# Shadog - Encrypt string

## Usage:
### install with pip:
```shell
pip install shadog
```

### Import on your code:
```python
from shadog import crypto

test = crypto.sha512('Teste')

print(test)
```